from distutils.core import setup

setup(
	name 		= 'asveloper_nester',
	version 	= '1.3.0',
	py_modules 	= ['asveloper_nester'],
	author 		= 'Arslan Nasir',
	author_email 	= 'arslan@asveloper.com',
	url 		= 'http://www.asveloper.com',
	description 	= 'Nester allow you to print lists either nested list exists or not'
)
